@@ -17,14 +17,13 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import os
-from glob import glob
+from pathlib import Path
 
 from gi.repository import GObject, Gtk
 
 from refine import settings
-from refine.widgets.combo_row import ComboRow
 from refine.widgets.base import InvalidSettingError
+from refine.widgets.combo_row import ComboRow
 
 
 @Gtk.Template.from_resource("/page/tesk/Refine/widgets/data-combo-row.ui")
@@ -45,42 +44,34 @@ class DataComboRow(ComboRow):
         if not (string := self.settings.get_string(self.key)):
             raise InvalidSettingError
 
-        system_data_dirs_list = []
+        system_data_dirs_list: list[Path] = []
         for directory in settings.get_system_data_dirs():
-            found_directories = glob(
-                f"{os.path.join(directory, self.data_subdirectory)}{os.sep}*"
-            )
+            found_directories = Path(directory, self.data_subdirectory).glob("*")
             system_data_dirs_list += found_directories
 
         data_dirs_list = system_data_dirs_list
 
-        data_dirs_list += glob(
-            f"{os.path.join(settings.get_user_data_dir(), self.data_subdirectory)}{os.sep}/*"
-        )
+        data_dirs_list += Path(
+            settings.get_user_data_dir(), self.data_subdirectory
+        ).glob("*")
 
         if bool(self.lookup_directory):
-            temp_dirs_list = []
-            for directory in data_dirs_list:
-                if os.path.isdir(os.path.join(directory, self.lookup_directory)):
-                    temp_dirs_list.append(directory)
-            data_dirs_list = temp_dirs_list
+            data_dirs_list = [
+                path
+                for path in data_dirs_list
+                if Path(path, self.lookup_directory).is_dir()
+            ]
 
-        data_dirs_list = list(
-            set(
-                map(
-                    os.path.basename,
-                    filter(lambda directory: os.path.isdir(directory), data_dirs_list),
-                )
-            )
-        )
+        data_dirs_list = [path.name for path in data_dirs_list if path.is_dir()]
 
         if self.aliases_dict:
-            data_dirs_list = list(
-                map(lambda item: self.aliases_dict.get(item, item), data_dirs_list)
-            )
+            data_dirs_list = [
+                self.aliases_dict.get(str(path), path) for path in data_dirs_list
+            ]
 
-        self.original_list = sorted(data_dirs_list, key=str.lower)
-        self.transformed_list = self.original_list
+        self.original_list = self.transformed_list = sorted(
+            [str(path) for path in data_dirs_list], key=str.lower
+        )
 
         data_dirs_model = Gtk.StringList.new(self.transformed_list)
         self.set_model(data_dirs_model)
@@ -101,4 +92,6 @@ class DataComboRow(ComboRow):
         aliases_list = aliases.split()
 
         # Credit: https://stackoverflow.com/a/12739974
-        self.aliases_dict = dict(zip(aliases_list[::2], aliases_list[1::2]))
+        self.aliases_dict = dict(
+            zip(aliases_list[::2], aliases_list[1::2], strict=False)
+        )
